function [M] = full_func_graph(s) 
% Function that creates the Full Functional Connected Graph
% where two proteins are connected not only if they are in interaction
% but also if they share any similar functional terms
% Weights are added according to the normalized Jacquard Index

	s.gene2term(s.gene2term == 2) = 1;
	n = size(s.intx,1);
	M = zeros(n,n);

	for i = 1:n
	 % fprintf(['Calculating Mij for i= ' num2str(i) '\n']);
	  bi = find(s.gene2term(i,:)); % terms of i
	  i_neigh = find(s.intx(i,:)); % neighbours of i
	  i_tneigh = []; % list of the proteins that share same terms
	  for j = 1:numel(bi) % for each of the terms of i
	   i_tneigh = cat(1, i_tneigh, find(s.gene2term(:, bi(j)))); % find the proteins with that term
	  end
	  i_tneigh = setdiff(unique(i_tneigh), i_neigh); % select unique proteins
	  
	  for j = 1:numel(i_neigh) % for each true interaction neighbour of i
		bj = find(s.gene2term(i_neigh(j),:)); % find its terms
		if(isempty(bi)) % if protein i has no annotations, add the annotations of its neighbours
		 for k = 1:numel(i_neigh)
		   if(k ~= i_neigh(j))
			 k_terms = find(s.gene2term(i_neigh(k),:));
			 bi = union(bi, k_terms); 
		   end
		 end
	   end
	   if(isempty(bj)) % same if protein j in not annotated
		 j_neigh = find(s.intx(i_neigh(j),:));
		 for k = 1:numel(j_neigh)
		   k_terms = find(s.gene2term(j_neigh(k),:));
		   if(k ~= i)
			 bj = union(bj, k_terms);
		   end
		 end
	   end
	   insec = numel(intersect(bi,bj));
	   un = numel(union(bi,bj));
	   if(insec == 0) % if the nodes don't share any similar terms
		M(i,i_neigh(j))=1; % the weight is 1 to emphasise the importance of the real interaction
	   else
		 M(i,i_neigh(j)) = 1/2*(insec/numel(bj)+insec/numel(bi))+1;  % else the weight is calc. by formula and 1 is added to emphasise the importance of the real interaction
	   end     
	  end
	  for j = 1:numel(i_tneigh) % repeat the same for the virtual neighbours of i
		bj = find(s.gene2term(i_tneigh(j),:));
		if(isempty(bi))
		 for k = 1:numel(i_tneigh)
		   if(k ~= i_tneigh(j))
			 k_terms = find(s.gene2term(i_tneigh(k),:));
			 bi = union(bi, k_terms);
		   end
		 end
	   end
	   if(isempty(bj))
		 j_neigh = find(s.intx(i_tneigh(j),:));
		 for k = 1:numel(j_neigh)
		   k_terms = find(s.gene2term(j_neigh(k),:));
		   if(k ~= i)
			 bj = union(bj, k_terms);
		   end
		 end
	   end
	   insec = numel(intersect(bi,bj));
	   if(insec == 0)
		M(i,i_tneigh(j))=0; % if the nodes don't share any similar terms and are not in interaction the weigth is 0
	   else 
		 M(i,i_tneigh(j)) = 1/2*(insec/numel(bj)+insec/numel(bi));  % else is calc. by the formula
	   end     
	 end
	end
end