function [M, MH, H] = weighted_graphs(s) 
% Function that creates the structure, content and hybrid based matrices
% described in Blockeel H, Rahmani H, Witsenburg T (2010) 
% Weights are added according to the normalized Jacquard Index

	A = s.intx;
	s.gene2term(s.gene2term == 2) = 1;
	n = size(s.intx,1);
	M = zeros(n,n); % M is the content based matrix
	for i = 1:n
	  bi = find(s.gene2term(i,:)); %find the annotations for protein i
	  i_neigh = find(s.intx(i,:)); % find the interactions for protein i
	  for j = 1:numel(i_neigh) % for each of the neighbour proteins of i
		bj = find(s.gene2term(i_neigh(j),:)); % find its annotations
		if(isempty(bi)) % if the protein has no annotations assign the annotations of its neighbours
		 for k = 1:numel(i_neigh) 
		   if(k ~= i_neigh(j))
			 k_terms = find(s.gene2term(i_neigh(k),:));
			 bi = union(bi, k_terms); 
		   end
		 end
	   end
	   if(isempty(bj)) % if some of the neighbours is not annotated
		 j_neigh = find(s.intx(i_neigh(j),:)); % find the union of terms of its neighbours
		 for k = 1:numel(j_neigh)
		   k_terms = find(s.gene2term(j_neigh(k),:));
		   if(k ~= i)
			 bj = union(bj, k_terms);
		   end
		 end
	   end
	   insec = numel(intersect(bi,bj));
	   if(insec == 0) % if the proteins don't have any similar functions assign value of 0.01, since they are in interaction anyway
		M(i,i_neigh(j))=0.01;
		elseif((~isempty(bj)) && (~isempty(bi)))       
		 M(i, i_neigh(j)) = 1/2*(insec/numel(bj)+insec/numel(bi)); % calculate the value by the formula given
	   elseif(isempty(bj))
		 M(i, i_neigh(j)) = 1/2*(insec/numel(bi));
	   elseif(isempty(bi))
		M(i, i_neigh(j)) = 1/2*(insec/numel(bj));
	   end     
	 end
	end

	MH = 1/2*(M*A + A*M); % MH is the structure based matrix
	H = 1/2*(M + MH); % H is the hybrid matrix
end